<?php

global $newuser_text;
$newuser_text = array (

'registernewuser'	=>	'Registra nuovo utente',
'requiredfields'	=>	'I campi obbligatori sono identificati con un',
'username'			=>	'Username',
'password'			=>	'Password',
'confirmpass'		=>	'Conferma Password',
'realname'			=>	'Nome vero',
'emailaddress'		=>	'Indirizzo e-mail',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Notifiche',
'none'				=>	'Nessuna',
'email'				=>	'e-mail',
'jabber'			=>	'Jabber',
//'group'				=>	'Group',
'registeraccount'	=>	'Registra questo account',

// New in 0.9.7

'globalgroup'		=>	'Gruppo globale',

);
?>
